## Welcome to Dathost’s unofficial python wrapper!
This is a unofficial asynchronous & synchronous wrapper for Dathost’s API.

### Features:
- Full API coverage.
- Asynchronous & synchronous support.
- Easy to use with an object oriented design.
- 100% test coverage.

### Install
- Pip: ``pip3 install dathost``
- Git: ``pip3 install git+https://github.com/WardPearce/dathost.git``


### Documentation
[Documentation](https://dathost.readthedocs.io/en/latest/)


### Thanks to
- [Encode for creating HTTPX](https://www.python-httpx.org/)
- [bcahue for his steam ID converting gist](https://github.com/bcahue)
